#' @import utils

utils::globalVariables(
  c(
    "unreliable_regions",
    "nucleotide_info",
    "virus_segments",
    "trained_rf",
    "trained_en",
    "trained_xgb",
    "Sample_ID",
    "Virus_name",
    "Segment_ID",
    "Isolate_ID",
    "Prediction"
  )
)
